@@ -7,7 +7,7 @@
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
-# Copyright 2011-2023 Univention GmbH
+# Copyright 2011-2024 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -609,7 +609,7 @@ class Instance(umcm.Base, ProgressMixin):
         """Query to fill the grid. Structure is fixed here."""
         result = []
         for package in self.package_manager.packages(reopen=True):
-            if section == 'all' or package.section == section:
+            if section in ('all', package.section):
                 toshow = False
                 if pattern.pattern == '^.*$':
                     toshow = True
